@@ -1,11 +1,12 @@
+from __future__ import annotations
+
 import errno
 import logging
 import os
 import subprocess
 
-from atomicwrites import atomic_write
-
 from .. import exceptions
+from ..utils import atomic_write
 from ..utils import checkdir
 from ..utils import expand_path
 from ..utils import generate_href
@@ -18,7 +19,6 @@ logger = logging.getLogger(__name__)
 
 
 class FilesystemStorage(Storage):
-
     storage_name = "filesystem"
     _repr_attributes = ["path"]
 
@@ -28,6 +28,7 @@ class FilesystemStorage(Storage):
         fileext,
         encoding="utf-8",
         post_hook=None,
+        pre_deletion_hook=None,
         fileignoreext=".tmp",
         **kwargs,
     ):
@@ -39,6 +40,7 @@ class FilesystemStorage(Storage):
         self.fileext = fileext
         self.fileignoreext = fileignoreext
         self.post_hook = post_hook
+        self.pre_deletion_hook = pre_deletion_hook
 
     @classmethod
     async def discover(cls, path, **kwargs):
@@ -165,6 +167,9 @@ class FilesystemStorage(Storage):
         actual_etag = get_etag_from_file(fpath)
         if etag != actual_etag:
             raise exceptions.WrongEtagError(etag, actual_etag)
+        if self.pre_deletion_hook:
+            self._run_pre_deletion_hook(fpath)
+
         os.remove(fpath)
 
     def _run_post_hook(self, fpath):
@@ -174,6 +179,15 @@ class FilesystemStorage(Storage):
         except OSError as e:
             logger.warning(f"Error executing external hook: {str(e)}")
 
+    def _run_pre_deletion_hook(self, fpath):
+        logger.info(
+            f"Calling pre_deletion_hook={self.pre_deletion_hook} with argument={fpath}"
+        )
+        try:
+            subprocess.call([self.pre_deletion_hook, fpath])
+        except OSError as e:
+            logger.warning(f"Error executing external hook: {str(e)}")
+
     async def get_meta(self, key):
         fpath = os.path.join(self.path, key)
         try:
